@@ -3,28 +3,31 @@ use crate::{info, ok, warn};
 use std::fmt::Debug;
 
 pub trait OptionLog {
-    fn log(&self);
-    fn show_none(&self);
-    fn show_some(&self);
+    fn log(self) -> Self;
+    fn show_none(self) -> Self;
+    fn show_some(self) -> Self;
 }
 
 impl<T: Debug> OptionLog for Option<T> {
-    fn log(&self) {
+    fn log(self) -> Self {
         match self {
-            Some(x) => ok!("obtained {x:?}"),
+            Some(ref x) => ok!("obtained {x:?}"),
             None => warn!("nothing obtained"),
         };
+        self
     }
 
-    fn show_none(&self) {
+    fn show_none(self) -> Self {
         if let None = self {
             info!("contains nothing");
         }
+        self
     }
 
-    fn show_some(&self) {
-        if let Some(x) = self {
+    fn show_some(self) -> Self {
+        if let Some(ref x) = self {
             info!("contains {x:?}");
         }
+        self
     }
 }
