@@ -4,7 +4,7 @@ use std::thread;
 #[test]
 fn multithread() {
     info!("Application started");
-    let thrds: Vec<_> = (0..=1000)
+    let thrds: Vec<_> = (0..=10)
         .map(|x| {
             thread::spawn(move || {
                 ok!("{x}th thread initialized");
@@ -26,3 +26,20 @@ fn pretty_out() {
     warn!("wait, is it really working {n}?");
     error!("OHHHH NOOOO");
 }
+
+#[test]
+fn result() {
+    #[cfg(feature = "impls")]
+    {
+        use crate::impls::*;
+        let n: Result<u8, ()> = Ok(2);
+        let m: Result<u8, ()> = Err(());
+        let exec = |f: fn(&Result<u8, ()>)| {
+            f(&n);
+            f(&m);
+        };
+        exec(ResultLog::log);
+        exec(ShowOk::show_ok);
+        exec(ShowErr::show_err);
+    }
+}
